<template>
  <div class="app-container">
    <div class="filter-container">
      <el-input v-model="listQuery.keyword" size="small" placeholder="请输入编号/名称/卡号" clearable class="filter-item w-200" />
      <el-button-group class="filter-item">
        <el-button size="small" type="primary" icon="el-icon-search" @click="search">
          搜索
        </el-button>
        <el-button size="small" type="primary" icon="el-icon-refresh" @click="refresh">
          刷新
        </el-button>
        <el-button v-if="uadd=='Yes'" size="small" type="primary" icon="el-icon-plus" @click="add">
          新增
        </el-button>
      </el-button-group>
    </div>

    <el-table v-loading="listLoading" :data="list" element-loading-text="Loading" border fit height="100%"
      class="table-container" highlight-current-row>
      <el-table-column label="ID" width="60" >
        <template slot-scope="scope">
          {{ scope.row.id }}
        </template>
      </el-table-column>
      <el-table-column label="编号" width="60">
        <template slot-scope="scope">
          {{ scope.row.tagid }}
        </template>
      </el-table-column>
      <el-table-column label="名称"  width="130">
        <template slot-scope="scope">
          {{ scope.row.anchorname }}
        </template>
      </el-table-column>
      <el-table-column label="公司"  width="170">
        <template slot-scope="scope">
          {{ scope.row.company }}
        </template>
      </el-table-column>
      <el-table-column label="状态" width="80">

        <template slot-scope="scope">
                            <span v-if="scope.row.onlie == '1'"><img src="../../assets/images/online6.png"></span>
                            <span v-else-if="scope.row.onlie == '0'"><img src="../../assets/images/offline4.png"></span>
                        </template>
        
      </el-table-column>

      <!-- <el-table-column label="电量" width="60">
        <template slot-scope="scope">
          {{ scope.row.electricity }}
        </template>
      </el-table-column> -->
      <el-table-column label="版本" width="60">
        <template slot-scope="scope">
          {{ scope.row.banben }}
        </template>
      </el-table-column>
      <el-table-column label="卫星" width="60">
        <template slot-scope="scope">
          {{ scope.row.gpsnum }}
        </template>
      </el-table-column>
      <el-table-column label="基准" width="60">
        <template slot-scope="scope">
          {{ scope.row.needbaseid }}
        </template>
      </el-table-column>
      <el-table-column label="卡号"  width="190">
        <template slot-scope="scope">
          {{ scope.row.cid }}
        </template>
      </el-table-column>
      <el-table-column label="经度" width="120">
        <template slot-scope="scope">
          {{ scope.row.lon }}
        </template>
      </el-table-column>
      <el-table-column label="纬度" width="120">
        <template slot-scope="scope">
          {{ scope.row.lat }}
        </template>
      </el-table-column>
      <el-table-column label="高程" >
        <template slot-scope="scope">
          {{ scope.row.height }}
        </template>
      </el-table-column>
      <el-table-column label="初始位移" >
        <template slot-scope="scope">
          {{  scope.row.ed0 +','+scope.row.nd0+','+scope.row.hd0 }}
        </template>
      </el-table-column>

      <!-- <el-table-column label="初始东" >
        <template slot-scope="scope">
          {{ scope.row.ed0 }}
        </template>
      </el-table-column>
      <el-table-column label="初始北" >
        <template slot-scope="scope">
          {{ scope.row.nd0 }}
        </template>
      </el-table-column>
      <el-table-column label="初始天" >
        <template slot-scope="scope">
          {{ scope.row.hd0 }}
        </template>
      </el-table-column> -->
      <el-table-column label="时间" >
        <template slot-scope="scope">
          {{ scope.row.addtime }}
        </template>
      </el-table-column>
      <el-table-column label="操作" width="200"  v-if="uupdate=='Yes' || udelete=='Yes'">
        <template slot-scope="scope">
          <el-button-group>
            <el-button  v-show="uupdate=='Yes'" type="primary" icon="el-icon-edit" size="mini" @click="edit(scope)">
              修改
            </el-button>
            <el-button  v-show="udelete=='Yes'" type="danger" icon="el-icon-delete" size="mini" @click="del(scope)">
              删除
            </el-button>
          </el-button-group>
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total > 0" :total="total" :page.sync="listQuery.current" :limit.sync="listQuery.size"
      @pagination="fetchData" />

    <el-dialog :visible.sync="dialogVisible" :title="dialogType === 'modify' ? '修改' : '新增'">
      <el-form :ref="temp" :model="temp" label-width="120px" label-position="right" :rules="rules">
        <el-form-item label="编号" prop="tagid" >
          <el-input v-model="temp.tagid
        " placeholder="请输入编号" :readonly="disabled"/>
        </el-form-item>
        <el-form-item label="名称" prop="anchorname">
          <el-input v-model="temp.anchorname
        " placeholder="请输入名称" />
        </el-form-item>
        <el-form-item label="公司" prop="companyid">
          <el-select style="width: 100%;" v-model="temp.company" filterable remote placeholder="请选择公司"
            :remote-method="searchMethod" :loading="searchloading">
            <el-option v-for="item in options" :key="item.id" :label="item.companyname" :value="item.id">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="基准" prop="needbaseid">
          <el-input v-model="temp.needbaseid
        " placeholder="请输入基准" />
        </el-form-item>
      </el-form>
      <div class="text-right">
        <el-button type="danger" @click="dialogVisible = false">
          取消
        </el-button>
        <el-button type="primary" @click="submit(temp)">
          确定
        </el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import Pagination from '@/components/Pagination'
import { getList, delEquipment, addorupEquipment, searchEquipment, search,addSystemOperationLog } from '@/api/equipment'
import { deepClone } from '@/utils'

const _temp = {
  id: '',
  anchorname: '',
  tagid: '',
  companyid: '',
  needbaseid: '',
  type: 1
}

export default {
  components: {
    Pagination
  },
  data() {
    return {
      disabled:false,
      uadd:'',
      udelete:'',
      uupdate:'',
      total: 0,
      list: [],
      menus: [],
      listLoading: true,
      listQuery: {
        username: localStorage.getItem('username') || '',
        current: 1,
        size: 20,
        keyword: undefined,
        type: 1
      },
      uploadUrl: '',
      temp: Object.assign({}, _temp),
      dialogVisible: false,
      dialogType: 'create',
      loading: false,
      value: '',
      options: [],
      searchloading: false,
      rules: {
        tagid: [
            { required: true, message: '请输入编号', trigger: 'blur' },
          ],
          anchorname: [
            { required: true, message: '请数据名称', trigger: 'blur' }
          ],
          companyid: [
            {  required: true, message: '请选择公司', trigger: 'change' }
          ],
          needbaseid: [
            {  required: true, message: '请输入基准', trigger: 'blur' }
          ]
        }
    }
  },
  created() {
    this.fetchData()
  },
  methods: {
    // 远程搜索
    searchMethod(query) {
      if (query !== '') {
        this.loading = true;
        var params = { query: query }
        search(params).then(response => {
          this.options = response.data;
          this.loading = false;
        })
      } else {
        this.options = [];
      }
    },
    // 搜索
    search() {
      this.listLoading = true
      searchEquipment(this.listQuery).then(response => {
        this.list = response.data.records
        this.total = response.data.total
        this.listLoading = false
      })
    },
    refresh() {
      this.listQuery = {
        username: localStorage.getItem('username') || '',
        current: 1,
        size: 20,
        keyword: undefined,
        type:1
      }
      this.fetchData()
    },
    // 分页数据
    fetchData() {
      this.uadd = localStorage.getItem('uadd') || '';
      this.udelete = localStorage.getItem('udelete') || '';
      this.uupdate = localStorage.getItem('uupdate') || '';
      this.listLoading = true
      getList(this.listQuery).then(response => {
        this.list = response.data.records
        this.total = response.data.total
        this.listLoading = false
      })
    },
    resetTemp() {
      this.temp = Object.assign({}, _temp)
    },
    add() {
      this.resetTemp()
      this.dialogVisible = true
      this.dialogType = 'create'
      this.disabled=false
      // this.$nextTick(() => {
      //   this.$refs['dataForm'].clearValidate()
      // })
    },
    edit(scope) {
      this.resetTemp()
      this.dialogVisible = true
      this.dialogType = 'modify'
      this.temp = deepClone(scope.row)
      this.disabled=true
      // this.$nextTick(() => {
      //   this.$refs['dataForm'].clearValidate()
      // })
    },
    changeStatus(value, scope) {
      setTimeout(() => {
        this.list[scope.$index].status = value
        this.$message({
          message: '更新成功',
          type: 'success'
        })
      }, 300)
    },
    // 删除
    del(scope) {
      this.$confirm('确认删除该条数据吗？', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        setTimeout(() => {
          const params = { id: scope.row.id };
          this.list.splice(scope.$index, 1)
          delEquipment(params).then(response => {
            this.temp.adminname = localStorage.getItem('username') || '';
            const params = { name:  this.temp.adminname, content: '删除了一个基准站，该编号为：'+scope.row.tagid };
            addSystemOperationLog(params).then(response => {

                        })
            this.$message({
              message: '删除成功',
              type: 'success'
            })
            this.fetchData()
          })
        }, 300)
      })
    },
    submit(formName) {
      if (this.loading) {
        return
      }
      this.temp.companyid=this.temp.company
      this.$refs[this.temp].validate((valid) => {
          if (valid) {
            this.loading = true
      addorupEquipment(this.temp).then(() => {
        if (this.temp.id=="") {
          this.temp.adminname = localStorage.getItem('username') || '';
            const params = { name:  this.temp.adminname, content: '新增了一个基准站，该编号为：'+this.temp.tagid };
            addSystemOperationLog(params).then(response => {

                        })
        } else {
          this.temp.adminname = localStorage.getItem('username') || '';
            const params = { name:  this.temp.adminname, content: '修改了一个基准站，该编号为：'+this.temp.tagid };
            addSystemOperationLog(params).then(response => {

                        })
        }
        this.fetchData()
        setTimeout(() => {
          this.$message({
            message: '提交成功',
            type: 'success'
          })
          this.dialogVisible = false
          this.loading = false
        }, 300)
      })
            // alert('submit!');
          } else {
            this.$message({
            message: '提交失败，请检查表单必填项是否为空',
            type: 'error'
          })
            console.log('error submit!!');
            return false;
          }
        });
    
   
    }
  }
}
</script>

<style lang="scss" scoped>
.el-upload {
  border: 1px dashed #d9d9d9 !important;
  border-radius: 6px;
  cursor: pointer;
  position: relative;
  overflow: hidden;

  .el-icon-plus.avatar-uploader-icon {
    border: 1px dashed #d9d9d9 !important;
    border-radius: 6px;
    font-size: 28px;
    color: #8c939d;
    width: 128px;
    height: 128px;
    line-height: 128px;
    text-align: center;
  }
}

.avatar-uploader {
  height: 128px;

  img {
    width: 128px;
    height: 128px;
  }
}
</style>
